<?php

namespace Drupal\azure_key_vault;

use Drupal\Core\Config\ConfigManagerInterface;

/**
 * Class AzureKeyVaultConfigurationService.
 *
 * Provide support fucntions to access API configuration settings.
 */
class AzureKeyVaultConfigurationService {

  /**
   * Drupal\Core\Config\ConfigManagerInterface definition.
   *
   * @var \Drupal\Core\Config\ConfigManagerInterface
   */
  protected $configManager;

  /**
   * Constructs a new AzureKeyVaultConfigurationService object.
   */
  public function __construct(ConfigManagerInterface $config_manager) {
    $this->configManager = $config_manager;
  }

  /**
   * Get Azure Key Vault URL.
   */
  public function getUrl() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('azure_url');
  }

  /**
   * Get OAuth token URL.
   */
  public function getTokenUrl() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('token_url');
  }

  /**
   * Get Client ID.
   */
  public function getClientId() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('client_id');
  }

  /**
   * Get Client Secret.
   */
  public function getClientSecret() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('client_secret');
  }

  /**
   * Get API Version Date.
   */
  public function getApiVersionDate() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('api_version_date');
  }

  /**
   * Get API Version Number.
   */
  public function getApiVersionNumber() {
    return $this->configManager->getConfigFactory()->get('azure_key_vault.settings')->get('api_version_number');
  }

}
